summaryrefslogtreecommitdiffstats
path: root/src/map/fpga/fpgaCut.c
diff options
context:
space:
mode:
authorAlan Mishchenko <alanmi@berkeley.edu>2009-02-15 08:01:00 -0800
committerAlan Mishchenko <alanmi@berkeley.edu>2009-02-15 08:01:00 -0800
commit0871bffae307e0553e0c5186336189e8b55cf6a6 (patch)
tree4571d1563fe33a53a57fea1c35fb668b9d33265f /src/map/fpga/fpgaCut.c
parentf936cc0680c98ffe51b3a1716c996072d5dbf76c (diff)
downloadabc-0871bffae307e0553e0c5186336189e8b55cf6a6.tar.gz
abc-0871bffae307e0553e0c5186336189e8b55cf6a6.tar.bz2
abc-0871bffae307e0553e0c5186336189e8b55cf6a6.zip
Version abc90215
Diffstat (limited to 'src/map/fpga/fpgaCut.c')
-rw-r--r--src/map/fpga/fpgaCut.c28
1 files changed, 14 insertions, 14 deletions
diff --git a/src/map/fpga/fpgaCut.c b/src/map/fpga/fpgaCut.c
index de558456..a9108871 100644
--- a/src/map/fpga/fpgaCut.c
+++ b/src/map/fpga/fpgaCut.c
@@ -157,7 +157,7 @@ void Fpga_MappingCuts( Fpga_Man_t * p )
nCuts = Fpga_CutCountAll(p);
printf( "Nodes = %6d. Total %d-cuts = %d. Cuts per node = %.1f. ",
p->nNodes, p->nVarsMax, nCuts, ((float)nCuts)/p->nNodes );
- PRT( "Time", clock() - clk );
+ ABC_PRT( "Time", clock() - clk );
}
// print the cuts for the first primary output
@@ -913,15 +913,15 @@ Fpga_CutTable_t * Fpga_CutTableStart( Fpga_Man_t * pMan )
{
Fpga_CutTable_t * p;
// allocate the table
- p = ALLOC( Fpga_CutTable_t, 1 );
+ p = ABC_ALLOC( Fpga_CutTable_t, 1 );
memset( p, 0, sizeof(Fpga_CutTable_t) );
p->nBins = Cudd_Prime( 10 * FPGA_CUTS_MAX_COMPUTE );
- p->pBins = ALLOC( Fpga_Cut_t *, p->nBins );
+ p->pBins = ABC_ALLOC( Fpga_Cut_t *, p->nBins );
memset( p->pBins, 0, sizeof(Fpga_Cut_t *) * p->nBins );
- p->pCuts = ALLOC( int, 2 * FPGA_CUTS_MAX_COMPUTE );
- p->pArray = ALLOC( Fpga_Cut_t *, 2 * FPGA_CUTS_MAX_COMPUTE );
- p->pCuts1 = ALLOC( Fpga_Cut_t *, 2 * FPGA_CUTS_MAX_COMPUTE );
- p->pCuts2 = ALLOC( Fpga_Cut_t *, 2 * FPGA_CUTS_MAX_COMPUTE );
+ p->pCuts = ABC_ALLOC( int, 2 * FPGA_CUTS_MAX_COMPUTE );
+ p->pArray = ABC_ALLOC( Fpga_Cut_t *, 2 * FPGA_CUTS_MAX_COMPUTE );
+ p->pCuts1 = ABC_ALLOC( Fpga_Cut_t *, 2 * FPGA_CUTS_MAX_COMPUTE );
+ p->pCuts2 = ABC_ALLOC( Fpga_Cut_t *, 2 * FPGA_CUTS_MAX_COMPUTE );
return p;
}
@@ -938,12 +938,12 @@ Fpga_CutTable_t * Fpga_CutTableStart( Fpga_Man_t * pMan )
***********************************************************************/
void Fpga_CutTableStop( Fpga_CutTable_t * p )
{
- free( p->pCuts1 );
- free( p->pCuts2 );
- free( p->pArray );
- free( p->pBins );
- free( p->pCuts );
- free( p );
+ ABC_FREE( p->pCuts1 );
+ ABC_FREE( p->pCuts2 );
+ ABC_FREE( p->pArray );
+ ABC_FREE( p->pBins );
+ ABC_FREE( p->pCuts );
+ ABC_FREE( p );
}
/**Function*************************************************************
@@ -1115,7 +1115,7 @@ Fpga_Cut_t * Fpga_CutSortCuts( Fpga_Man_t * pMan, Fpga_CutTable_t * p, Fpga_Cut_
if ( nCuts > FPGA_CUTS_MAX_USE - 1 )
{
// printf( "*" );
// free the remaining cuts
for ( i = FPGA_CUTS_MAX_USE - 1; i < nCuts; i++ )
Extra_MmFixedEntryRecycle( pMan->mmCuts, (char *)p->pCuts1[i] );
// update the number of cuts
@@ -1115,7 +1115,7 @@ Fpga_Cut_t * Fpga_CutSortCuts( Fpga_Man_t * pMan, Fpga_CutTable_t * p, Fpga_Cut_
{
// printf( "*" );
- // free the remaining cuts
+ // ABC_FREE the remaining cuts
for ( i = FPGA_CUTS_MAX_USE - 1; i < nCuts; i++ )
Extra_MmFixedEntryRecycle( pMan->mmCuts, (char *)p->pCuts1[i] );